package product

import (
	"net/http"

	"tyc-server/app/main/api/internal/logic/product"
	"tyc-server/app/main/api/internal/svc"
	"tyc-server/app/main/api/internal/types"
	"tyc-server/common/result"
	"tyc-server/pkg/lzkit/validator"

	"github.com/zeromicro/go-zero/rest/httpx"
)

func GetProductRenderListHandler(svcCtx *svc.ServiceContext) http.HandlerFunc {
	return func(w http.ResponseWriter, r *http.Request) {
		var req types.GetProductRenderListRequest
		if err := httpx.Parse(r, &req); err != nil {
			result.ParamErrorResult(r, w, err)
			return
		}
		if err := validator.Validate(req); err != nil {
			result.ParamValidateErrorResult(r, w, err)
			return
		}
		l := product.NewGetProductRenderListLogic(r.Context(), svcCtx)
		resp, err := l.GetProductRenderList(&req)
		result.HttpResult(r, w, resp, err)
	}
}
