package product

import (
	"context"
	"tyc-server/app/main/api/internal/svc"
	"tyc-server/app/main/api/internal/types"
	"tyc-server/app/main/model"
	"tyc-server/common/xerr"

	"github.com/Masterminds/squirrel"
	"github.com/jinzhu/copier"
	"github.com/pkg/errors"
	"github.com/zeromicro/go-zero/core/mr"

	"github.com/zeromicro/go-zero/core/logx"
)

type GetProductRenderListLogic struct {
	logx.Logger
	ctx    context.Context
	svcCtx *svc.ServiceContext
}

func NewGetProductRenderListLogic(ctx context.Context, svcCtx *svc.ServiceContext) *GetProductRenderListLogic {
	return &GetProductRenderListLogic{
		Logger: logx.WithContext(ctx),
		ctx:    ctx,
		svcCtx: svcCtx,
	}
}

func (l *GetProductRenderListLogic) GetProductRenderList(req *types.GetProductRenderListRequest) (resp *types.GetProductRenderListResponse, err error) {
	platform, platformOk := l.ctx.Value("platform").(string)
	if !platformOk || platform == "" {
		return nil, errors.Wrapf(xerr.NewErrCode(xerr.SERVER_COMMON_ERROR), "获取渲染列表失败，没有相关平台信息")
	}
	// 从上下文中获取品牌信息
	brand, brandOk := l.ctx.Value("brand").(string)
	if !brandOk || brand == "" {
		return nil, errors.Wrapf(xerr.NewErrCode(xerr.SERVER_COMMON_ERROR), "获取渲染列表失败，没有相关品牌信息")
	}

	var platformKey = brand + "_" + platform
	builder := l.svcCtx.ProductRenderModel.SelectBuilder().Where(squirrel.Eq{
		"platform": platformKey,
		"module":   req.Module,
	})
	productRenderModelList, err := l.svcCtx.ProductRenderModel.FindAll(l.ctx, builder, "")
	if err != nil {
		return nil, errors.Wrapf(xerr.NewErrCode(xerr.DB_ERROR), "获取渲染列表失败，获取渲染列表失败%s", err.Error())
	}
	var productList []types.Product
	mr.MapReduceVoid(func(source chan<- interface{}) {
		for _, productRender := range productRenderModelList {
			if productRender.IsRendered == 1 {
				source <- productRender.ProductId
			}
		}
	}, func(item interface{}, writer mr.Writer[*model.Product], cancel func(error)) {
		id := item.(int64)
		product, findProductErr := l.svcCtx.ProductModel.FindOne(l.ctx, id)
		if findProductErr != nil {
			logx.WithContext(l.ctx).Errorf("获取渲染列表失败, 查找关联product错误: %d, err:%v", id, findProductErr)
			return
		}
		if product != nil && product.Id > 0 {
			product.Description = ""
			product.SellPrice = 0
			writer.Write(product)
		}
	}, func(pipe <-chan *model.Product, cancel func(error)) {
		for item := range pipe {
			var product types.Product
			_ = copier.Copy(&product, item)
			productList = append(productList, product)
		}
	})
	return &types.GetProductRenderListResponse{
		Product: productList,
	}, nil
}
