package main

import (
	"context"
	"flag"
	"fmt"
	"os"
	"tyc-server/app/main/api/internal/config"
	"tyc-server/app/main/api/internal/handler"
	middleware "tyc-server/app/main/api/internal/middleware/global"
	"tyc-server/app/main/api/internal/queue"
	"tyc-server/app/main/api/internal/svc"

	"github.com/zeromicro/go-zero/core/logx"

	"github.com/zeromicro/go-zero/core/conf"
	"github.com/zeromicro/go-zero/rest"
)

func main() {
	// 读取环境变量 ENV，默认为 "prod"
	env := os.Getenv("ENV")
	if env == "" {
		env = "production"
	}

	// 根据 ENV 加载不同的配置文件
	var defaultConfigFile string
	if env == "development" {
		defaultConfigFile = "app/main/api/etc/main.dev.yaml"
	} else {
		defaultConfigFile = "etc/main.yaml" // 生产环境配置
	}
	configFile := flag.String("f", defaultConfigFile, "the config file")
	flag.Parse()

	var c config.Config
	conf.MustLoad(*configFile, &c)

	svcContext := svc.NewServiceContext(c)
	defer svcContext.Close()

	// 启动 asynq 消费者
	go func() {
		ctx := context.Background()
		// 初始化 cron job 或异步任务队列
		asynq := queue.NewCronJob(ctx, svcContext)
		mux := asynq.Register()

		// 启动 asynq 消费者
		if err := svcContext.AsynqServer.Run(mux); err != nil {
			logx.WithContext(ctx).Errorf("异步任务启动失败: %+v", err)
			os.Exit(1)
		}
		fmt.Println("异步任务启动！！！")
	}()
	// go func() {
	// 	script.RunEncryptMobile()
	// }()
	server := rest.MustNewServer(c.RestConf)

	// 全局中间件
	server.Use(middleware.ReqHeaderCtxMiddleware)

	defer server.Stop()

	handler.RegisterHandlers(server, svcContext)

	fmt.Printf("Starting server at %s:%d...\n", c.Host, c.Port)
	server.Start()
}
